@@ -14,8 +14,8 @@
 
     Last commit info:
     ~~~~~~~~~~~~~~~~~
-    $LastChangedDate: 2009-04-30 15:41:53 +0200 (Do, 30 Apr 2009) $
-    $Rev: 30 $
+    $LastChangedDate: 2009-06-03 09:56:08 +0200 (Mi, 03 Jun 2009) $
+    $Rev: 37 $
     $Author: google.groups@jensdiemer.de $
 
     :copyleft: 2008-2009 by python-creole team, see AUTHORS for more details.
@@ -349,6 +349,18 @@ class TestCreole2htmlMarkup(BaseCreoleTest):
         """,
             verbose=0
         )
+        
+    def test_image(self):
+        """ test image tag with different picture text """
+        self.assertCreole(r"""
+            {{foobar1.jpg}}
+            {{/foobar2.jpg|foobar2.jpg}}
+            {{/path1/path2/foobar3.jpg|foobar3.jpg}}
+        """, """
+            <p><img src="foobar1.jpg" alt="foobar1.jpg" /><br />
+            <img src="/foobar2.jpg" alt="foobar2.jpg" /><br />
+            <img src="/path1/path2/foobar3.jpg" alt="foobar3.jpg" /></p>
+        """)
 
 
 if __name__ == '__main__':
